Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(296)

Unified Diff: ui/gfx/canvas.h

Issue 2502373003: stop using SkXfermode -- use SkBlendMode instead (Closed)
Patch Set: rebase Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/compositor/compositing_recorder.cc ('k') | ui/gfx/canvas.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/gfx/canvas.h
diff --git a/ui/gfx/canvas.h b/ui/gfx/canvas.h
index 521a1567f4a9835c2eb90992823fe550004a4941..40ce0bff4015abdf63006037de85f6b769985f8e 100644
--- a/ui/gfx/canvas.h
+++ b/ui/gfx/canvas.h
@@ -38,9 +38,9 @@ class Transform;
// or if converting from a scalar to an integer |SkScalarRound()|.
//
// A handful of methods in this class are overloaded providing an additional
// argument of type SkXfermode::Mode. SkXfermode::Mode specifies how the
// source and destination colors are combined. Unless otherwise specified,
// the variant that does not take a SkXfermode::Mode uses a transfer mode
// of kSrcOver_Mode.
class GFX_EXPORT Canvas {
public:
@@ -215,22 +215,22 @@ class GFX_EXPORT Canvas {
void Scale(int x_scale, int y_scale);
// Fills the entire canvas' bitmap (restricted to current clip) with
// specified |color| using a transfer mode of SkXfermode::kSrcOver_Mode.
void DrawColor(SkColor color);
// Fills the entire canvas' bitmap (restricted to current clip) with
// specified |color| and |mode|.
- void DrawColor(SkColor color, SkXfermode::Mode mode);
+ void DrawColor(SkColor color, SkBlendMode mode);
// Fills |rect| with |color| using a transfer mode of
- // SkXfermode::kSrcOver_Mode.
+ // SkBlendMode::kSrcOver.
void FillRect(const Rect& rect, SkColor color);
// Fills |rect| with the specified |color| and |mode|.
- void FillRect(const Rect& rect, SkColor color, SkXfermode::Mode mode);
+ void FillRect(const Rect& rect, SkColor color, SkBlendMode mode);
// Draws a single pixel rect in the specified region with the specified
// color, using a transfer mode of SkXfermode::kSrcOver_Mode.
//
// NOTE: if you need a single pixel line, use DrawLine.
// DEPRECATED in favor of the RectF version below.
@@ -238,7 +238,7 @@ class GFX_EXPORT Canvas {
void DrawRect(const Rect& rect, SkColor color);
// Draws a single pixel rect in the specified region with the specified
// color, using a transfer mode of SkXfermode::kSrcOver_Mode.
//
// NOTE: if you need a single pixel line, use DrawLine.
void DrawRect(const RectF& rect, SkColor color);
@@ -249,13 +249,13 @@ class GFX_EXPORT Canvas {
// NOTE: if you need a single pixel line, use DrawLine.
// DEPRECATED in favor of the RectF version below.
// TODO(funkysidd): Remove this (http://crbug.com/553726)
- void DrawRect(const Rect& rect, SkColor color, SkXfermode::Mode mode);
+ void DrawRect(const Rect& rect, SkColor color, SkBlendMode mode);
// Draws a single pixel rect in the specified region with the specified
// color and transfer mode.
//
// NOTE: if you need a single pixel line, use DrawLine.
- void DrawRect(const RectF& rect, SkColor color, SkXfermode::Mode mode);
+ void DrawRect(const RectF& rect, SkColor color, SkBlendMode mode);
// Draws the given rectangle with the given |paint| parameters.
// DEPRECATED in favor of the RectF version below.
« no previous file with comments | « ui/compositor/compositing_recorder.cc ('k') | ui/gfx/canvas.cc » ('j') | no next file with comments »
@@ -38,9 +38,9 @@ class Transform;
//
// A handful of methods in this class are overloaded providing an additional
-// argument of type SkXfermode::Mode. SkXfermode::Mode specifies how the
+// argument of type SkBlendMode. SkBlendMode specifies how the
// source and destination colors are combined. Unless otherwise specified,
@@ -38,9 +38,9 @@ class Transform;
// source and destination colors are combined. Unless otherwise specified,
-// the variant that does not take a SkXfermode::Mode uses a transfer mode
+// the variant that does not take a SkBlendMode uses a transfer mode
// of kSrcOver_Mode.
class GFX_EXPORT Canvas {
@@ -215,22 +215,22 @@ class GFX_EXPORT Canvas {
void Scale(int x_scale, int y_scale);
// Fills the entire canvas' bitmap (restricted to current clip) with
- // specified |color| using a transfer mode of SkXfermode::kSrcOver_Mode.
+ // specified |color| using a transfer mode of SkBlendMode::kSrcOver.
void DrawColor(SkColor color);
// Fills the entire canvas' bitmap (restricted to current clip) with
@@ -215,22 +215,22 @@ class GFX_EXPORT Canvas {
// Draws a single pixel rect in the specified region with the specified
- // color, using a transfer mode of SkXfermode::kSrcOver_Mode.
+ // color, using a transfer mode of SkBlendMode::kSrcOver.
//
// NOTE: if you need a single pixel line, use DrawLine.
@@ -238,7 +238,7 @@ class GFX_EXPORT Canvas {
void DrawRect(const Rect& rect, SkColor color);
// Draws a single pixel rect in the specified region with the specified
- // color, using a transfer mode of SkXfermode::kSrcOver_Mode.
+ // color, using a transfer mode of SkBlendMode::kSrcOver.
//
// NOTE: if you need a single pixel line, use DrawLine.

Powered by Google App Engine
This is Rietveld 408576698